==> digikam-0.10.0.tar.bz2: digikam-0.10.0/libs/imageproperties/imagepropertiesmetadatatab.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2004-11-17
 * Description : a tab to display metadata information of images
 *
 * Copyright (C) 2004-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEPROPERTIESMETADATATAB_H
#define IMAGEPROPERTIESMETADATATAB_H

// Qt includes.

#include <QWidget>

// KDE includes.

#include <kurl.h>
#include <ktabwidget.h>

// Local includes.

#include "digikam_export.h"
#include "dmetadata.h"

namespace Digikam
{

class ImagePropertiesMetadataTabPriv;

class DIGIKAM_EXPORT ImagePropertiesMetaDataTab : public KTabWidget
{
    Q_OBJECT

public:

    ImagePropertiesMetaDataTab(QWidget* parent);
    ~ImagePropertiesMetaDataTab();

    void setCurrentURL(const KUrl& url=KUrl());
    void setCurrentData(const DMetadata& metadata=DMetadata(), 
                        const QString& filename=QString());

private:

    ImagePropertiesMetadataTabPriv* const d;
};

}  // namespace Digikam

#endif /* IMAGEPROPERTIESMETADATATAB_H */

==> digikam-1.3.0.tar.bz2: digikam-1.3.0/libs/imageproperties/imagepropertiesmetadatatab.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2004-11-17
 * Description : a tab to display metadata information of images
 *
 * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEPROPERTIESMETADATATAB_H
#define IMAGEPROPERTIESMETADATATAB_H

// Qt includes

#include <QWidget>

// KDE includes

#include <kurl.h>
#include <ktabwidget.h>

// Local includes

#include "digikam_export.h"
#include "dmetadata.h"

namespace Digikam
{

class ImagePropertiesMetadataTabPriv;

class DIGIKAM_EXPORT ImagePropertiesMetaDataTab : public KTabWidget
{
    Q_OBJECT

public:

    ImagePropertiesMetaDataTab(QWidget* parent);
    ~ImagePropertiesMetaDataTab();

    void applySettings();

    void setCurrentURL(const KUrl& url=KUrl());
    void setCurrentData(const DMetadata& metadata=DMetadata(), 
                        const QString& filename=QString());

private:

    void readSettings();
    void writeSettings();

private:

    ImagePropertiesMetadataTabPriv* const d;
};

}  // namespace Digikam

#endif /* IMAGEPROPERTIESMETADATATAB_H */
